/********************************************************************************
** Form generated from reading UI file 'importerconfigdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORTERCONFIGDIALOG_H
#define UI_IMPORTERCONFIGDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ImporterConfigDialog
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_AutoRename;
    QWidget *widget;
    QGridLayout *gridLayout_2;
    QLabel *label;
    KLineEdit *kcfg_AutoRenameFormat;
    QLabel *mPreviewOutputLabel;
    QLabel *label_2;
    QLabel *mRenameFormatHelpLabel;
    QLabel *label_3;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ImporterConfigDialog)
    {
        if (ImporterConfigDialog->objectName().isEmpty())
            ImporterConfigDialog->setObjectName("ImporterConfigDialog");
        ImporterConfigDialog->resize(410, 213);
        verticalLayout = new QVBoxLayout(ImporterConfigDialog);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_AutoRename = new QCheckBox(ImporterConfigDialog);
        kcfg_AutoRename->setObjectName("kcfg_AutoRename");

        verticalLayout->addWidget(kcfg_AutoRename);

        widget = new QWidget(ImporterConfigDialog);
        widget->setObjectName("widget");
        widget->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(widget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(24, -1, -1, -1);
        label = new QLabel(widget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label, 2, 0, 1, 1);

        kcfg_AutoRenameFormat = new KLineEdit(widget);
        kcfg_AutoRenameFormat->setObjectName("kcfg_AutoRenameFormat");

        gridLayout_2->addWidget(kcfg_AutoRenameFormat, 2, 1, 1, 1);

        mPreviewOutputLabel = new QLabel(widget);
        mPreviewOutputLabel->setObjectName("mPreviewOutputLabel");
        mPreviewOutputLabel->setText(QString::fromUtf8("[Output preview]"));

        gridLayout_2->addWidget(mPreviewOutputLabel, 3, 1, 1, 1);

        label_2 = new QLabel(widget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_2, 3, 0, 1, 1);

        mRenameFormatHelpLabel = new QLabel(widget);
        mRenameFormatHelpLabel->setObjectName("mRenameFormatHelpLabel");
        mRenameFormatHelpLabel->setText(QString::fromUtf8("- {date}: shooting date\n"
"- {name}: original file name"));
        mRenameFormatHelpLabel->setWordWrap(true);
        mRenameFormatHelpLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse);

        gridLayout_2->addWidget(mRenameFormatHelpLabel, 5, 0, 1, 2);

        label_3 = new QLabel(widget);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 0, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 24, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_2, 4, 0, 1, 2);

        verticalSpacer_3 = new QSpacerItem(20, 24, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_2->addItem(verticalSpacer_3, 1, 0, 1, 2);


        verticalLayout->addWidget(widget);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ImporterConfigDialog);
        QObject::connect(kcfg_AutoRename, &QCheckBox::toggled, widget, &QWidget::setEnabled);

        QMetaObject::connectSlotsByName(ImporterConfigDialog);
    } // setupUi

    void retranslateUi(QWidget *ImporterConfigDialog)
    {
        kcfg_AutoRename->setText(tr2i18n("Rename documents automatically", nullptr));
        label->setText(tr2i18n("Rename Format:", nullptr));
        label_2->setText(tr2i18n("Preview:", nullptr));
        label_3->setText(tr2i18n("<i>Type text or click the items below to customize the format</i>", nullptr));
        (void)ImporterConfigDialog;
    } // retranslateUi

};

namespace Ui {
    class ImporterConfigDialog: public Ui_ImporterConfigDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORTERCONFIGDIALOG_H

