/********************************************************************************
** Form generated from reading UI file 'printoptionspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PRINTOPTIONSPAGE_H
#define UI_PRINTOPTIONSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PrintOptionsPage
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout;
    QFrame *mPositionFrame;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *mNoScale;
    QRadioButton *mScaleToPage;
    QHBoxLayout *hboxLayout;
    QSpacerItem *spacerItem;
    QCheckBox *kcfg_PrintEnlargeSmallerImages;
    QSpacerItem *spacerItem1;
    QRadioButton *mScaleTo;
    QGridLayout *gridLayout;
    QSpacerItem *spacerItem2;
    QDoubleSpinBox *kcfg_PrintWidth;
    QLabel *textLabel2;
    QDoubleSpinBox *kcfg_PrintHeight;
    QComboBox *kcfg_PrintUnit;
    QSpacerItem *spacerItem3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_PrintKeepRatio;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *spacerItem4;

    void setupUi(QWidget *PrintOptionsPage)
    {
        if (PrintOptionsPage->objectName().isEmpty())
            PrintOptionsPage->setObjectName("PrintOptionsPage");
        PrintOptionsPage->resize(511, 252);
        gridLayout_2 = new QGridLayout(PrintOptionsPage);
        gridLayout_2->setObjectName("gridLayout_2");
        groupBox_2 = new QGroupBox(PrintOptionsPage);
        groupBox_2->setObjectName("groupBox_2");
        verticalLayout = new QVBoxLayout(groupBox_2);
        verticalLayout->setObjectName("verticalLayout");
        mPositionFrame = new QFrame(groupBox_2);
        mPositionFrame->setObjectName("mPositionFrame");

        verticalLayout->addWidget(mPositionFrame);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout_2->addWidget(groupBox_2, 0, 0, 1, 1);

        groupBox = new QGroupBox(PrintOptionsPage);
        groupBox->setObjectName("groupBox");
        verticalLayout_2 = new QVBoxLayout(groupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mNoScale = new QRadioButton(groupBox);
        mNoScale->setObjectName("mNoScale");
        mNoScale->setChecked(true);

        verticalLayout_2->addWidget(mNoScale);

        mScaleToPage = new QRadioButton(groupBox);
        mScaleToPage->setObjectName("mScaleToPage");
        mScaleToPage->setChecked(false);

        verticalLayout_2->addWidget(mScaleToPage);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName("hboxLayout");
        spacerItem = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem);

        kcfg_PrintEnlargeSmallerImages = new QCheckBox(groupBox);
        kcfg_PrintEnlargeSmallerImages->setObjectName("kcfg_PrintEnlargeSmallerImages");
        kcfg_PrintEnlargeSmallerImages->setEnabled(false);

        hboxLayout->addWidget(kcfg_PrintEnlargeSmallerImages);

        spacerItem1 = new QSpacerItem(24, 21, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(spacerItem1);


        verticalLayout_2->addLayout(hboxLayout);

        mScaleTo = new QRadioButton(groupBox);
        mScaleTo->setObjectName("mScaleTo");

        verticalLayout_2->addWidget(mScaleTo);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem2, 0, 0, 1, 1);

        kcfg_PrintWidth = new QDoubleSpinBox(groupBox);
        kcfg_PrintWidth->setObjectName("kcfg_PrintWidth");
        kcfg_PrintWidth->setEnabled(false);
        kcfg_PrintWidth->setValue(15.000000000000000);

        gridLayout->addWidget(kcfg_PrintWidth, 0, 1, 1, 1);

        textLabel2 = new QLabel(groupBox);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setWordWrap(false);

        gridLayout->addWidget(textLabel2, 0, 2, 1, 1);

        kcfg_PrintHeight = new QDoubleSpinBox(groupBox);
        kcfg_PrintHeight->setObjectName("kcfg_PrintHeight");
        kcfg_PrintHeight->setEnabled(false);
        kcfg_PrintHeight->setValue(10.000000000000000);

        gridLayout->addWidget(kcfg_PrintHeight, 0, 3, 1, 1);

        kcfg_PrintUnit = new QComboBox(groupBox);
        kcfg_PrintUnit->addItem(QString());
        kcfg_PrintUnit->addItem(QString());
        kcfg_PrintUnit->addItem(QString());
        kcfg_PrintUnit->setObjectName("kcfg_PrintUnit");
        kcfg_PrintUnit->setEnabled(false);

        gridLayout->addWidget(kcfg_PrintUnit, 0, 4, 1, 1);

        spacerItem3 = new QSpacerItem(24, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem3, 0, 5, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_PrintKeepRatio = new QCheckBox(groupBox);
        kcfg_PrintKeepRatio->setObjectName("kcfg_PrintKeepRatio");
        kcfg_PrintKeepRatio->setEnabled(false);
        kcfg_PrintKeepRatio->setChecked(true);

        horizontalLayout->addWidget(kcfg_PrintKeepRatio);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 1, 1, 1, 5);


        verticalLayout_2->addLayout(gridLayout);


        gridLayout_2->addWidget(groupBox, 0, 1, 1, 1);

        spacerItem4 = new QSpacerItem(20, 16, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(spacerItem4, 1, 0, 1, 2);


        retranslateUi(PrintOptionsPage);
        QObject::connect(mScaleTo, &QRadioButton::toggled, kcfg_PrintUnit, &QComboBox::setEnabled);
        QObject::connect(mScaleTo, &QRadioButton::toggled, kcfg_PrintKeepRatio, &QCheckBox::setEnabled);
        QObject::connect(mScaleToPage, &QRadioButton::toggled, kcfg_PrintEnlargeSmallerImages, &QCheckBox::setEnabled);
        QObject::connect(mScaleTo, &QRadioButton::toggled, kcfg_PrintWidth, &QDoubleSpinBox::setEnabled);
        QObject::connect(mScaleTo, &QRadioButton::toggled, kcfg_PrintHeight, &QDoubleSpinBox::setEnabled);

        kcfg_PrintUnit->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(PrintOptionsPage);
    } // setupUi

    void retranslateUi(QWidget *PrintOptionsPage)
    {
        PrintOptionsPage->setWindowTitle(tr2i18n("Image Settings", nullptr));
        groupBox_2->setTitle(tr2i18n("Image Position", nullptr));
        groupBox->setTitle(tr2i18n("Scaling", nullptr));
        mNoScale->setText(tr2i18n("&No scaling", nullptr));
        mScaleToPage->setText(tr2i18n("&Fit image to page", nullptr));
        kcfg_PrintEnlargeSmallerImages->setText(tr2i18n("Enlarge smaller images", nullptr));
        mScaleTo->setText(tr2i18n("&Scale to:", nullptr));
        textLabel2->setText(tr2i18n("x", "Dimension separator, as in: '15 x 10 centimeters'"));
        kcfg_PrintUnit->setItemText(0, tr2i18n("Millimeters", nullptr));
        kcfg_PrintUnit->setItemText(1, tr2i18n("Centimeters", nullptr));
        kcfg_PrintUnit->setItemText(2, tr2i18n("Inches", nullptr));

        kcfg_PrintKeepRatio->setText(tr2i18n("Keep ratio", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PrintOptionsPage: public Ui_PrintOptionsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PRINTOPTIONSPAGE_H

