/********************************************************************************
** Form generated from reading UI file 'thumbnailpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_THUMBNAILPAGE_H
#define UI_THUMBNAILPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <lib/thumbnailview/thumbnailslider.h>
#include <lib/thumbnailview/thumbnailview.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ThumbnailPage
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout_2;
    QLabel *mSrcIconLabel;
    QSpacerItem *verticalSpacer_2;
    QLabel *mDstIconLabel;
    QWidget *widget;
    QVBoxLayout *verticalLayout;
    QSplitter *splitter;
    QTreeView *mSrcUrlTreeView;
    Gwenview::ThumbnailView *mThumbnailView;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    Gwenview::ThumbnailSlider *mSlider;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *mConfigureButton;
    QDialogButtonBox *mButtonBox;
    QLabel *label;
    KUrlRequester *mDstUrlRequester;
    QWidget *widget_2;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    QPushButton *mSrcUrlButton;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *ThumbnailPage)
    {
        if (ThumbnailPage->objectName().isEmpty())
            ThumbnailPage->setObjectName("ThumbnailPage");
        ThumbnailPage->resize(437, 487);
        ThumbnailPage->setStyleSheet(QString::fromUtf8("QLabel[isTitle=true] { font-weight: bold }\n"
"\n"
"QLabel[isIcon=true] {\n"
"	border: 1px solid palette(mid);\n"
"	background-color: palette(base);\n"
"	padding: 12px;\n"
"}"));
        gridLayout = new QGridLayout(ThumbnailPage);
        gridLayout->setObjectName("gridLayout");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        mSrcIconLabel = new QLabel(ThumbnailPage);
        mSrcIconLabel->setObjectName("mSrcIconLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mSrcIconLabel->sizePolicy().hasHeightForWidth());
        mSrcIconLabel->setSizePolicy(sizePolicy);
        mSrcIconLabel->setText(QString::fromUtf8("[icon]"));
        mSrcIconLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        mSrcIconLabel->setProperty("isIcon", QVariant(true));

        verticalLayout_2->addWidget(mSrcIconLabel);

        verticalSpacer_2 = new QSpacerItem(20, 13, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer_2);

        mDstIconLabel = new QLabel(ThumbnailPage);
        mDstIconLabel->setObjectName("mDstIconLabel");
        sizePolicy.setHeightForWidth(mDstIconLabel->sizePolicy().hasHeightForWidth());
        mDstIconLabel->setSizePolicy(sizePolicy);
        mDstIconLabel->setText(QString::fromUtf8("[icon]"));
        mDstIconLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        mDstIconLabel->setProperty("isIcon", QVariant(true));

        verticalLayout_2->addWidget(mDstIconLabel);


        gridLayout->addLayout(verticalLayout_2, 0, 0, 5, 1);

        widget = new QWidget(ThumbnailPage);
        widget->setObjectName("widget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy1);
        verticalLayout = new QVBoxLayout(widget);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        splitter = new QSplitter(widget);
        splitter->setObjectName("splitter");
        sizePolicy1.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy1);
        splitter->setOrientation(Qt::Horizontal);
        mSrcUrlTreeView = new QTreeView(splitter);
        mSrcUrlTreeView->setObjectName("mSrcUrlTreeView");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(1);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mSrcUrlTreeView->sizePolicy().hasHeightForWidth());
        mSrcUrlTreeView->setSizePolicy(sizePolicy2);
        mSrcUrlTreeView->setFrameShape(QFrame::NoFrame);
        mSrcUrlTreeView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        mSrcUrlTreeView->setProperty("showDropIndicator", QVariant(false));
        mSrcUrlTreeView->setHeaderHidden(true);
        splitter->addWidget(mSrcUrlTreeView);
        mThumbnailView = new Gwenview::ThumbnailView(splitter);
        mThumbnailView->setObjectName("mThumbnailView");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(4);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(mThumbnailView->sizePolicy().hasHeightForWidth());
        mThumbnailView->setSizePolicy(sizePolicy3);
        splitter->addWidget(mThumbnailView);

        verticalLayout->addWidget(splitter);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        mSlider = new Gwenview::ThumbnailSlider(widget);
        mSlider->setObjectName("mSlider");
        sizePolicy.setHeightForWidth(mSlider->sizePolicy().hasHeightForWidth());
        mSlider->setSizePolicy(sizePolicy);
        mSlider->setMinimumSize(QSize(150, 0));

        horizontalLayout->addWidget(mSlider);


        verticalLayout->addLayout(horizontalLayout);


        gridLayout->addWidget(widget, 2, 1, 1, 1);

        label_2 = new QLabel(ThumbnailPage);
        label_2->setObjectName("label_2");
        label_2->setProperty("isTitle", QVariant(true));

        gridLayout->addWidget(label_2, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mConfigureButton = new QPushButton(ThumbnailPage);
        mConfigureButton->setObjectName("mConfigureButton");

        horizontalLayout_2->addWidget(mConfigureButton);

        mButtonBox = new QDialogButtonBox(ThumbnailPage);
        mButtonBox->setObjectName("mButtonBox");
        mButtonBox->setStandardButtons(QDialogButtonBox::Cancel);

        horizontalLayout_2->addWidget(mButtonBox);


        gridLayout->addLayout(horizontalLayout_2, 5, 0, 1, 2);

        label = new QLabel(ThumbnailPage);
        label->setObjectName("label");
        label->setProperty("isTitle", QVariant(true));

        gridLayout->addWidget(label, 3, 1, 1, 1);

        mDstUrlRequester = new KUrlRequester(ThumbnailPage);
        mDstUrlRequester->setObjectName("mDstUrlRequester");

        gridLayout->addWidget(mDstUrlRequester, 4, 1, 1, 1);

        widget_2 = new QWidget(ThumbnailPage);
        widget_2->setObjectName("widget_2");
        horizontalLayout_3 = new QHBoxLayout(widget_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_3 = new QLabel(widget_2);
        label_3->setObjectName("label_3");

        horizontalLayout_3->addWidget(label_3);

        mSrcUrlButton = new QPushButton(widget_2);
        mSrcUrlButton->setObjectName("mSrcUrlButton");

        horizontalLayout_3->addWidget(mSrcUrlButton);

        horizontalSpacer_2 = new QSpacerItem(56, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        gridLayout->addWidget(widget_2, 1, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(mDstUrlRequester);
        label_3->setBuddy(mSrcUrlButton);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(mSrcUrlButton, mSrcUrlTreeView);
        QWidget::setTabOrder(mSrcUrlTreeView, mThumbnailView);
        QWidget::setTabOrder(mThumbnailView, mDstUrlRequester);
        QWidget::setTabOrder(mDstUrlRequester, mConfigureButton);
        QWidget::setTabOrder(mConfigureButton, mButtonBox);

        retranslateUi(ThumbnailPage);

        QMetaObject::connectSlotsByName(ThumbnailPage);
    } // setupUi

    void retranslateUi(QWidget *ThumbnailPage)
    {
        label_2->setText(tr2i18n("Select the documents to import", nullptr));
        mConfigureButton->setText(tr2i18n("Settings...", nullptr));
        label->setText(tr2i18n("Enter the import destination", nullptr));
        label_3->setText(tr2i18n("Listing content of:", nullptr));
        (void)ThumbnailPage;
    } // retranslateUi

};

namespace Ui {
    class ThumbnailPage: public Ui_ThumbnailPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // THUMBNAILPAGE_H

