/****************************************************************************
** Meta object code from reading C++ file 'thumbnailpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/importer/thumbnailpage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'thumbnailpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::ThumbnailPage::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::ThumbnailPage",
        "importRequested",
        "",
        "rejected",
        "slotImportSelected",
        "slotImportAll",
        "updateImportButtons",
        "openUrl",
        "QUrl",
        "slotDocumentDirFinderDone",
        "url",
        "DocumentDirFinder::Status",
        "status",
        "showConfigDialog",
        "openUrlFromIndex",
        "QModelIndex",
        "index",
        "setupSrcUrlTreeView",
        "toggleSrcUrlTreeView",
        "slotSrcUrlModelExpand"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'importRequested'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rejected'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportSelected'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportAll'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateImportButtons'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'slotDocumentDirFinderDone'
        QtMocHelpers::SlotData<void(const QUrl &, DocumentDirFinder::Status)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'showConfigDialog'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openUrlFromIndex'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setupSrcUrlTreeView'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSrcUrlTreeView'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSrcUrlModelExpand'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ThumbnailPage, qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::ThumbnailPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>.metaTypes,
    nullptr
} };

void Gwenview::ThumbnailPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThumbnailPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->importRequested(); break;
        case 1: _t->rejected(); break;
        case 2: _t->slotImportSelected(); break;
        case 3: _t->slotImportAll(); break;
        case 4: _t->updateImportButtons(); break;
        case 5: _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->slotDocumentDirFinderDone((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DocumentDirFinder::Status>>(_a[2]))); break;
        case 7: _t->showConfigDialog(); break;
        case 8: _t->openUrlFromIndex((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->setupSrcUrlTreeView(); break;
        case 10: _t->toggleSrcUrlTreeView(); break;
        case 11: _t->slotSrcUrlModelExpand((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ThumbnailPage::*)()>(_a, &ThumbnailPage::importRequested, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailPage::*)()>(_a, &ThumbnailPage::rejected, 1))
            return;
    }
}

const QMetaObject *Gwenview::ThumbnailPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::ThumbnailPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailPageE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Gwenview::ThumbnailPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::ThumbnailPage::importRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gwenview::ThumbnailPage::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
