/********************************************************************************
** Form generated from reading UI file 'messageview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESSAGEVIEW_H
#define UI_MESSAGEVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <kmessagewidget.h>

QT_BEGIN_NAMESPACE

class Ui_MessageView
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer;
    KMessageWidget *mMessageWidget;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;

    void setupUi(QWidget *MessageView)
    {
        if (MessageView->objectName().isEmpty())
            MessageView->setObjectName("MessageView");
        MessageView->resize(400, 300);
        gridLayout = new QGridLayout(MessageView);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 125, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 0, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(120, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 0, 1, 1);

        mMessageWidget = new KMessageWidget(MessageView);
        mMessageWidget->setObjectName("mMessageWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mMessageWidget->sizePolicy().hasHeightForWidth());
        mMessageWidget->setSizePolicy(sizePolicy);
        mMessageWidget->setFrameShape(QFrame::NoFrame);
        mMessageWidget->setFrameShadow(QFrame::Raised);
        horizontalLayout = new QHBoxLayout(mMessageWidget);
        horizontalLayout->setObjectName("horizontalLayout");

        gridLayout->addWidget(mMessageWidget, 1, 1, 1, 2);

        horizontalSpacer_2 = new QSpacerItem(120, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 1, 3, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 125, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 2, 2, 1, 1);


        retranslateUi(MessageView);

        QMetaObject::connectSlotsByName(MessageView);
    } // setupUi

    void retranslateUi(QWidget *MessageView)
    {
        (void)MessageView;
    } // retranslateUi

};

namespace Ui {
    class MessageView: public Ui_MessageView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESSAGEVIEW_H

