/********************************************************************************
** Form generated from reading UI file 'dialogpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGPAGE_H
#define UI_DIALOGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_DialogPage
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QLabel *mLabel;
    QSpacerItem *verticalSpacer_4;
    QWidget *mButtonContainer;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    KMessageWidget *mErrorMessageWidget;

    void setupUi(QWidget *DialogPage)
    {
        if (DialogPage->objectName().isEmpty())
            DialogPage->setObjectName("DialogPage");
        DialogPage->resize(355, 287);
        gridLayout = new QGridLayout(DialogPage);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer_2 = new QSpacerItem(20, 55, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 3, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(178, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        mLabel = new QLabel(DialogPage);
        mLabel->setObjectName("mLabel");

        verticalLayout->addWidget(mLabel);

        verticalSpacer_4 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout->addItem(verticalSpacer_4);

        mButtonContainer = new QWidget(DialogPage);
        mButtonContainer->setObjectName("mButtonContainer");

        verticalLayout->addWidget(mButtonContainer);


        gridLayout->addLayout(verticalLayout, 2, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(177, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 2, 2, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 1, 1, 1, 1);

        mErrorMessageWidget = new KMessageWidget(DialogPage);
        mErrorMessageWidget->setObjectName("mErrorMessageWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mErrorMessageWidget->sizePolicy().hasHeightForWidth());
        mErrorMessageWidget->setSizePolicy(sizePolicy);
        mErrorMessageWidget->setMessageType(KMessageWidget::Error);

        gridLayout->addWidget(mErrorMessageWidget, 0, 0, 1, 3);


        retranslateUi(DialogPage);

        QMetaObject::connectSlotsByName(DialogPage);
    } // setupUi

    void retranslateUi(QWidget *DialogPage)
    {
        mLabel->setText(QString());
        (void)DialogPage;
    } // retranslateUi

};

namespace Ui {
    class DialogPage: public Ui_DialogPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DIALOGPAGE_H

