/****************************************************************************
** Meta object code from reading C++ file 'thumbnailprovider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/lib/thumbnailprovider/thumbnailprovider.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'thumbnailprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::ThumbnailProvider::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::ThumbnailProvider",
        "thumbnailLoaded",
        "",
        "KFileItem",
        "item",
        "QPixmap",
        "QSize",
        "thumbnailLoadingFailed",
        "finished",
        "determineNextIcon",
        "slotGotPreview",
        "checkThumbnail",
        "thumbnailReady",
        "QImage",
        "emitThumbnailLoadingFailed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'thumbnailLoaded'
        QtMocHelpers::SignalData<void(const KFileItem &, const QPixmap &, const QSize &, qulonglong)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 2 }, { 0x80000000 | 6, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Signal 'thumbnailLoadingFailed'
        QtMocHelpers::SignalData<void(const KFileItem &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'determineNextIcon'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGotPreview'
        QtMocHelpers::SlotData<void(const KFileItem &, const QPixmap &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Slot 'checkThumbnail'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'thumbnailReady'
        QtMocHelpers::SlotData<void(const QImage &, const QSize &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'emitThumbnailLoadingFailed'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ThumbnailProvider, qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::ThumbnailProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<KIO::Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>.metaTypes,
    nullptr
} };

void Gwenview::ThumbnailProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThumbnailProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->thumbnailLoaded((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[4]))); break;
        case 1: _t->thumbnailLoadingFailed((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 2: _t->finished(); break;
        case 3: _t->determineNextIcon(); break;
        case 4: _t->slotGotPreview((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 5: _t->checkThumbnail(); break;
        case 6: _t->thumbnailReady((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2]))); break;
        case 7: _t->emitThumbnailLoadingFailed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ThumbnailProvider::*)(const KFileItem & , const QPixmap & , const QSize & , qulonglong )>(_a, &ThumbnailProvider::thumbnailLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailProvider::*)(const KFileItem & )>(_a, &ThumbnailProvider::thumbnailLoadingFailed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailProvider::*)()>(_a, &ThumbnailProvider::finished, 2))
            return;
    }
}

const QMetaObject *Gwenview::ThumbnailProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::ThumbnailProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17ThumbnailProviderE_t>.strings))
        return static_cast<void*>(this);
    return KIO::Job::qt_metacast(_clname);
}

int Gwenview::ThumbnailProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KIO::Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::ThumbnailProvider::thumbnailLoaded(const KFileItem & _t1, const QPixmap & _t2, const QSize & _t3, qulonglong _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void Gwenview::ThumbnailProvider::thumbnailLoadingFailed(const KFileItem & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Gwenview::ThumbnailProvider::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
