/****************************************************************************
** Meta object code from reading C++ file 'viewmainpage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/app/viewmainpage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewmainpage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview12ViewMainPageE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::ViewMainPage::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::ViewMainPage",
        "completed",
        "",
        "previousImageRequested",
        "nextImageRequested",
        "openUrlRequested",
        "QUrl",
        "openDirUrlRequested",
        "toggleFullScreenRequested",
        "goToBrowseModeRequested",
        "captionUpdateRequested",
        "setStatusBarVisible",
        "setThumbnailBarVisibility",
        "visible",
        "showContextMenu",
        "slotViewFocused",
        "DocumentView*",
        "slotEnterPressed",
        "trashView",
        "deselectView",
        "slotDirModelItemsAddedOrRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousImageRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextImageRequested'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openUrlRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'openDirUrlRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'toggleFullScreenRequested'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goToBrowseModeRequested'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captionUpdateRequested'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setStatusBarVisible'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'setThumbnailBarVisibility'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotViewFocused'
        QtMocHelpers::SlotData<void(DocumentView *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'slotEnterPressed'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'trashView'
        QtMocHelpers::SlotData<void(DocumentView *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'deselectView'
        QtMocHelpers::SlotData<void(DocumentView *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 2 },
        }}),
        // Slot 'slotDirModelItemsAddedOrRemoved'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ViewMainPage, qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::ViewMainPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>.metaTypes,
    nullptr
} };

void Gwenview::ViewMainPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewMainPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed(); break;
        case 1: _t->previousImageRequested(); break;
        case 2: _t->nextImageRequested(); break;
        case 3: _t->openUrlRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->openDirUrlRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->toggleFullScreenRequested(); break;
        case 6: _t->goToBrowseModeRequested(); break;
        case 7: _t->captionUpdateRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setStatusBarVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setThumbnailBarVisibility((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->showContextMenu(); break;
        case 11: _t->slotViewFocused((*reinterpret_cast<std::add_pointer_t<DocumentView*>>(_a[1]))); break;
        case 12: _t->slotEnterPressed(); break;
        case 13: _t->trashView((*reinterpret_cast<std::add_pointer_t<DocumentView*>>(_a[1]))); break;
        case 14: _t->deselectView((*reinterpret_cast<std::add_pointer_t<DocumentView*>>(_a[1]))); break;
        case 15: _t->slotDirModelItemsAddedOrRemoved(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)()>(_a, &ViewMainPage::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)()>(_a, &ViewMainPage::previousImageRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)()>(_a, &ViewMainPage::nextImageRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)(const QUrl & )>(_a, &ViewMainPage::openUrlRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)(const QUrl & )>(_a, &ViewMainPage::openDirUrlRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)()>(_a, &ViewMainPage::toggleFullScreenRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)()>(_a, &ViewMainPage::goToBrowseModeRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewMainPage::*)(const QString & )>(_a, &ViewMainPage::captionUpdateRequested, 7))
            return;
    }
}

const QMetaObject *Gwenview::ViewMainPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::ViewMainPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12ViewMainPageE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Gwenview::ViewMainPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::ViewMainPage::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gwenview::ViewMainPage::previousImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Gwenview::ViewMainPage::nextImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Gwenview::ViewMainPage::openUrlRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Gwenview::ViewMainPage::openDirUrlRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Gwenview::ViewMainPage::toggleFullScreenRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Gwenview::ViewMainPage::goToBrowseModeRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Gwenview::ViewMainPage::captionUpdateRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
