/********************************************************************************
** Form generated from reading UI file 'fullscreenconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FULLSCREENCONFIGWIDGET_H
#define UI_FULLSCREENCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_FullScreenConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout_4;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QSlider *mSlideShowIntervalSlider;
    QLabel *mSlideShowIntervalLabel;
    QCheckBox *mSlideShowLoopCheckBox;
    QCheckBox *mSlideShowRandomCheckBox;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_3;
    QPushButton *mConfigureDisplayedInformationButton;
    QGroupBox *mThumbnailGroupBox;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *mShowThumbnailsCheckBox;
    QLabel *label_5;
    QSlider *mHeightSlider;

    void setupUi(QWidget *FullScreenConfigWidget)
    {
        if (FullScreenConfigWidget->objectName().isEmpty())
            FullScreenConfigWidget->setObjectName("FullScreenConfigWidget");
        FullScreenConfigWidget->resize(258, 312);
        FullScreenConfigWidget->setStyleSheet(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(FullScreenConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(FullScreenConfigWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        verticalLayout_4 = new QVBoxLayout(groupBox);
        verticalLayout_4->setObjectName("verticalLayout_4");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        verticalLayout_4->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mSlideShowIntervalSlider = new QSlider(groupBox);
        mSlideShowIntervalSlider->setObjectName("mSlideShowIntervalSlider");
        mSlideShowIntervalSlider->setMinimum(1);
        mSlideShowIntervalSlider->setMaximum(60);
        mSlideShowIntervalSlider->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(mSlideShowIntervalSlider);

        mSlideShowIntervalLabel = new QLabel(groupBox);
        mSlideShowIntervalLabel->setObjectName("mSlideShowIntervalLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mSlideShowIntervalLabel->sizePolicy().hasHeightForWidth());
        mSlideShowIntervalLabel->setSizePolicy(sizePolicy);
        mSlideShowIntervalLabel->setMinimumSize(QSize(30, 0));
        mSlideShowIntervalLabel->setText(QString::fromUtf8("[N secs]"));

        horizontalLayout->addWidget(mSlideShowIntervalLabel);


        verticalLayout_4->addLayout(horizontalLayout);

        mSlideShowLoopCheckBox = new QCheckBox(groupBox);
        mSlideShowLoopCheckBox->setObjectName("mSlideShowLoopCheckBox");

        verticalLayout_4->addWidget(mSlideShowLoopCheckBox);

        mSlideShowRandomCheckBox = new QCheckBox(groupBox);
        mSlideShowRandomCheckBox->setObjectName("mSlideShowRandomCheckBox");

        verticalLayout_4->addWidget(mSlideShowRandomCheckBox);


        verticalLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(FullScreenConfigWidget);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setFlat(true);
        verticalLayout_3 = new QVBoxLayout(groupBox_2);
        verticalLayout_3->setObjectName("verticalLayout_3");
        mConfigureDisplayedInformationButton = new QPushButton(groupBox_2);
        mConfigureDisplayedInformationButton->setObjectName("mConfigureDisplayedInformationButton");

        verticalLayout_3->addWidget(mConfigureDisplayedInformationButton);


        verticalLayout->addWidget(groupBox_2);

        mThumbnailGroupBox = new QGroupBox(FullScreenConfigWidget);
        mThumbnailGroupBox->setObjectName("mThumbnailGroupBox");
        mThumbnailGroupBox->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(mThumbnailGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mShowThumbnailsCheckBox = new QCheckBox(mThumbnailGroupBox);
        mShowThumbnailsCheckBox->setObjectName("mShowThumbnailsCheckBox");
        mShowThumbnailsCheckBox->setChecked(true);

        verticalLayout_2->addWidget(mShowThumbnailsCheckBox);

        label_5 = new QLabel(mThumbnailGroupBox);
        label_5->setObjectName("label_5");

        verticalLayout_2->addWidget(label_5);

        mHeightSlider = new QSlider(mThumbnailGroupBox);
        mHeightSlider->setObjectName("mHeightSlider");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mHeightSlider->sizePolicy().hasHeightForWidth());
        mHeightSlider->setSizePolicy(sizePolicy1);
        mHeightSlider->setMinimumSize(QSize(204, 0));
        mHeightSlider->setMinimum(70);
        mHeightSlider->setMaximum(256);
        mHeightSlider->setValue(70);
        mHeightSlider->setOrientation(Qt::Horizontal);

        verticalLayout_2->addWidget(mHeightSlider);


        verticalLayout->addWidget(mThumbnailGroupBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(mSlideShowIntervalSlider);
        label_5->setBuddy(mHeightSlider);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(mSlideShowIntervalSlider, mSlideShowLoopCheckBox);
        QWidget::setTabOrder(mSlideShowLoopCheckBox, mSlideShowRandomCheckBox);
        QWidget::setTabOrder(mSlideShowRandomCheckBox, mConfigureDisplayedInformationButton);
        QWidget::setTabOrder(mConfigureDisplayedInformationButton, mShowThumbnailsCheckBox);
        QWidget::setTabOrder(mShowThumbnailsCheckBox, mHeightSlider);

        retranslateUi(FullScreenConfigWidget);
        QObject::connect(mShowThumbnailsCheckBox, &QCheckBox::toggled, mHeightSlider, &QSlider::setEnabled);
        QObject::connect(mShowThumbnailsCheckBox, &QCheckBox::toggled, label_5, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(FullScreenConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *FullScreenConfigWidget)
    {
        groupBox->setTitle(tr2i18n("Slideshow", nullptr));
        label->setText(tr2i18n("Interval:", nullptr));
        mSlideShowLoopCheckBox->setText(tr2i18n("Loop", nullptr));
        mSlideShowRandomCheckBox->setText(tr2i18n("Random", nullptr));
        groupBox_2->setTitle(tr2i18n("Image Information", nullptr));
        mConfigureDisplayedInformationButton->setText(tr2i18n("Select Image Information to Display...", nullptr));
        mThumbnailGroupBox->setTitle(tr2i18n("Thumbnails", nullptr));
        mShowThumbnailsCheckBox->setText(tr2i18n("Show thumbnails", nullptr));
        label_5->setText(tr2i18n("Height:", nullptr));
        (void)FullScreenConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class FullScreenConfigWidget: public Ui_FullScreenConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FULLSCREENCONFIGWIDGET_H

