/********************************************************************************
** Form generated from reading UI file 'generalconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALCONFIGPAGE_H
#define UI_GENERALCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralConfigPage
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QCheckBox *kcfg_ListVideos;
    QCheckBox *kcfg_AutoplayVideos;
    QSpacerItem *verticalSpacer;
    QLabel *label_7;
    QRadioButton *neverShowWrapNoticeRadioButton;
    QRadioButton *wrapNoticeOnSlideshowRadioButton;
    QRadioButton *alwaysShowWrapNoticeRadioButton;
    QLabel *label_2;
    QCheckBox *kcfg_WrapAfterLast;
    QSpacerItem *verticalSpacer_1;
    QLabel *label_3;
    QRadioButton *fullscreenBackgroundImageRadioButton;
    QRadioButton *fullscreenBackgroundBlackRadioButton;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    QSlider *kcfg_JPEGQuality;
    QSpinBox *jpegQualitySpinner;
    QSpacerItem *horizontalSpacer;
    QLabel *lossyImageFormatHelpLabel;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_5;
    QRadioButton *allButtonsThumbnailActionsRadioButton;
    QRadioButton *selectionOnlyThumbnailActionsRadioButton;
    QRadioButton *noneThumbnailActionsRadioButton;

    void setupUi(QWidget *GeneralConfigPage)
    {
        if (GeneralConfigPage->objectName().isEmpty())
            GeneralConfigPage->setObjectName("GeneralConfigPage");
        GeneralConfigPage->resize(515, 493);
        formLayout = new QFormLayout(GeneralConfigPage);
        formLayout->setObjectName("formLayout");
        label = new QLabel(GeneralConfigPage);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_ListVideos = new QCheckBox(GeneralConfigPage);
        kcfg_ListVideos->setObjectName("kcfg_ListVideos");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_ListVideos);

        kcfg_AutoplayVideos = new QCheckBox(GeneralConfigPage);
        kcfg_AutoplayVideos->setObjectName("kcfg_AutoplayVideos");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_AutoplayVideos);

        verticalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(2, QFormLayout::ItemRole::FieldRole, verticalSpacer);

        label_7 = new QLabel(GeneralConfigPage);
        label_7->setObjectName("label_7");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_7);

        neverShowWrapNoticeRadioButton = new QRadioButton(GeneralConfigPage);
        neverShowWrapNoticeRadioButton->setObjectName("neverShowWrapNoticeRadioButton");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, neverShowWrapNoticeRadioButton);

        wrapNoticeOnSlideshowRadioButton = new QRadioButton(GeneralConfigPage);
        wrapNoticeOnSlideshowRadioButton->setObjectName("wrapNoticeOnSlideshowRadioButton");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, wrapNoticeOnSlideshowRadioButton);

        alwaysShowWrapNoticeRadioButton = new QRadioButton(GeneralConfigPage);
        alwaysShowWrapNoticeRadioButton->setObjectName("alwaysShowWrapNoticeRadioButton");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, alwaysShowWrapNoticeRadioButton);

        label_2 = new QLabel(GeneralConfigPage);
        label_2->setObjectName("label_2");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_WrapAfterLast = new QCheckBox(GeneralConfigPage);
        kcfg_WrapAfterLast->setObjectName("kcfg_WrapAfterLast");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_WrapAfterLast);

        verticalSpacer_1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(7, QFormLayout::ItemRole::FieldRole, verticalSpacer_1);

        label_3 = new QLabel(GeneralConfigPage);
        label_3->setObjectName("label_3");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_3);

        fullscreenBackgroundImageRadioButton = new QRadioButton(GeneralConfigPage);
        fullscreenBackgroundImageRadioButton->setObjectName("fullscreenBackgroundImageRadioButton");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, fullscreenBackgroundImageRadioButton);

        fullscreenBackgroundBlackRadioButton = new QRadioButton(GeneralConfigPage);
        fullscreenBackgroundBlackRadioButton->setObjectName("fullscreenBackgroundBlackRadioButton");

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, fullscreenBackgroundBlackRadioButton);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(10, QFormLayout::ItemRole::FieldRole, verticalSpacer_3);

        label_4 = new QLabel(GeneralConfigPage);
        label_4->setObjectName("label_4");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_JPEGQuality = new QSlider(GeneralConfigPage);
        kcfg_JPEGQuality->setObjectName("kcfg_JPEGQuality");
        kcfg_JPEGQuality->setMinimumSize(QSize(256, 0));
        kcfg_JPEGQuality->setMaximum(100);
        kcfg_JPEGQuality->setValue(90);
        kcfg_JPEGQuality->setSliderPosition(90);
        kcfg_JPEGQuality->setOrientation(Qt::Horizontal);
        kcfg_JPEGQuality->setTickPosition(QSlider::NoTicks);
        kcfg_JPEGQuality->setTickInterval(5);

        horizontalLayout->addWidget(kcfg_JPEGQuality);

        jpegQualitySpinner = new QSpinBox(GeneralConfigPage);
        jpegQualitySpinner->setObjectName("jpegQualitySpinner");
        jpegQualitySpinner->setMaximum(100);

        horizontalLayout->addWidget(jpegQualitySpinner);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        formLayout->setLayout(11, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        lossyImageFormatHelpLabel = new QLabel(GeneralConfigPage);
        lossyImageFormatHelpLabel->setObjectName("lossyImageFormatHelpLabel");
        lossyImageFormatHelpLabel->setWordWrap(true);

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, lossyImageFormatHelpLabel);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        formLayout->setItem(13, QFormLayout::ItemRole::FieldRole, verticalSpacer_4);

        label_5 = new QLabel(GeneralConfigPage);
        label_5->setObjectName("label_5");

        formLayout->setWidget(14, QFormLayout::ItemRole::LabelRole, label_5);

        allButtonsThumbnailActionsRadioButton = new QRadioButton(GeneralConfigPage);
        allButtonsThumbnailActionsRadioButton->setObjectName("allButtonsThumbnailActionsRadioButton");

        formLayout->setWidget(14, QFormLayout::ItemRole::FieldRole, allButtonsThumbnailActionsRadioButton);

        selectionOnlyThumbnailActionsRadioButton = new QRadioButton(GeneralConfigPage);
        selectionOnlyThumbnailActionsRadioButton->setObjectName("selectionOnlyThumbnailActionsRadioButton");

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, selectionOnlyThumbnailActionsRadioButton);

        noneThumbnailActionsRadioButton = new QRadioButton(GeneralConfigPage);
        noneThumbnailActionsRadioButton->setObjectName("noneThumbnailActionsRadioButton");

        formLayout->setWidget(16, QFormLayout::ItemRole::FieldRole, noneThumbnailActionsRadioButton);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_ListVideos);
        label_7->setBuddy(neverShowWrapNoticeRadioButton);
        label_3->setBuddy(fullscreenBackgroundImageRadioButton);
        label_4->setBuddy(kcfg_JPEGQuality);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ListVideos, kcfg_AutoplayVideos);
        QWidget::setTabOrder(kcfg_AutoplayVideos, neverShowWrapNoticeRadioButton);
        QWidget::setTabOrder(neverShowWrapNoticeRadioButton, wrapNoticeOnSlideshowRadioButton);
        QWidget::setTabOrder(wrapNoticeOnSlideshowRadioButton, alwaysShowWrapNoticeRadioButton);
        QWidget::setTabOrder(alwaysShowWrapNoticeRadioButton, fullscreenBackgroundImageRadioButton);
        QWidget::setTabOrder(fullscreenBackgroundImageRadioButton, fullscreenBackgroundBlackRadioButton);
        QWidget::setTabOrder(fullscreenBackgroundBlackRadioButton, kcfg_JPEGQuality);
        QWidget::setTabOrder(kcfg_JPEGQuality, jpegQualitySpinner);
        QWidget::setTabOrder(jpegQualitySpinner, allButtonsThumbnailActionsRadioButton);
        QWidget::setTabOrder(allButtonsThumbnailActionsRadioButton, selectionOnlyThumbnailActionsRadioButton);
        QWidget::setTabOrder(selectionOnlyThumbnailActionsRadioButton, noneThumbnailActionsRadioButton);

        retranslateUi(GeneralConfigPage);

        QMetaObject::connectSlotsByName(GeneralConfigPage);
    } // setupUi

    void retranslateUi(QWidget *GeneralConfigPage)
    {
        label->setText(tr2i18n("Videos:", nullptr));
        kcfg_ListVideos->setText(tr2i18n("Show videos", nullptr));
        kcfg_AutoplayVideos->setText(tr2i18n("Automatically play", nullptr));
        label_7->setText(tr2i18n("Notify after reaching the last image:", nullptr));
        neverShowWrapNoticeRadioButton->setText(tr2i18n("Never", nullptr));
        wrapNoticeOnSlideshowRadioButton->setText(tr2i18n("Only during slideshows", nullptr));
        alwaysShowWrapNoticeRadioButton->setText(tr2i18n("Always", nullptr));
        label_2->setText(tr2i18n("After the last image:", nullptr));
        kcfg_WrapAfterLast->setText(tr2i18n("Start over", nullptr));
        label_3->setText(tr2i18n("Fullscreen background:", nullptr));
        fullscreenBackgroundImageRadioButton->setText(tr2i18n("Dark gray texture", nullptr));
        fullscreenBackgroundBlackRadioButton->setText(tr2i18n("Black", nullptr));
        label_4->setText(tr2i18n("Lossy image save quality:", nullptr));
        jpegQualitySpinner->setSuffix(tr2i18n("%", nullptr));
        jpegQualitySpinner->setPrefix(QString());
        lossyImageFormatHelpLabel->setText(tr2i18n("The quality level when saving images using lossy image formats such as JPEG, WEBP, AVIF, HEIF, and HEIC. Higher quality increases the file size.", nullptr));
        label_5->setText(tr2i18n("Thumbnail actions:", nullptr));
        allButtonsThumbnailActionsRadioButton->setText(tr2i18n("All buttons", nullptr));
        selectionOnlyThumbnailActionsRadioButton->setText(tr2i18n("Show selection button only", nullptr));
        noneThumbnailActionsRadioButton->setText(tr2i18n("None", "A number of thumbnail actions to show"));
        (void)GeneralConfigPage;
    } // retranslateUi

};

namespace Ui {
    class GeneralConfigPage: public Ui_GeneralConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALCONFIGPAGE_H

