/****************************************************************************
** Meta object code from reading C++ file 'document.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/lib/document/document.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'document.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview8DocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::Document::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview8DocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::Document",
        "downSampledImageReady",
        "",
        "imageRectUpdated",
        "QRect",
        "kindDetermined",
        "QUrl",
        "metaInfoLoaded",
        "loaded",
        "loadingFailed",
        "saved",
        "oldUrl",
        "newUrl",
        "modified",
        "metaInfoUpdated",
        "isAnimatedUpdated",
        "busyChanged",
        "allTasksDone",
        "emitMetaInfoLoaded",
        "emitLoaded",
        "emitLoadingFailed",
        "slotSaveResult",
        "KJob*",
        "slotJobFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'downSampledImageReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageRectUpdated'
        QtMocHelpers::SignalData<void(const QRect &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'kindDetermined'
        QtMocHelpers::SignalData<void(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'metaInfoLoaded'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'loaded'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'loadingFailed'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'saved'
        QtMocHelpers::SignalData<void(const QUrl &, const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 11 }, { 0x80000000 | 6, 12 },
        }}),
        // Signal 'modified'
        QtMocHelpers::SignalData<void(const QUrl &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'metaInfoUpdated'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isAnimatedUpdated'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'busyChanged'
        QtMocHelpers::SignalData<void(const QUrl &, bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Signal 'allTasksDone'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emitMetaInfoLoaded'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitLoaded'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitLoadingFailed'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveResult'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Slot 'slotJobFinished'
        QtMocHelpers::SlotData<void(KJob *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Document, qt_meta_tag_ZN8Gwenview8DocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::Document::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview8DocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview8DocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview8DocumentE_t>.metaTypes,
    nullptr
} };

void Gwenview::Document::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Document *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->downSampledImageReady(); break;
        case 1: _t->imageRectUpdated((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 2: _t->kindDetermined((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->metaInfoLoaded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->loaded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->loadingFailed((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->saved((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 7: _t->modified((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->metaInfoUpdated(); break;
        case 9: _t->isAnimatedUpdated(); break;
        case 10: _t->busyChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: _t->allTasksDone(); break;
        case 12: _t->emitMetaInfoLoaded(); break;
        case 13: _t->emitLoaded(); break;
        case 14: _t->emitLoadingFailed(); break;
        case 15: _t->slotSaveResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 16: _t->slotJobFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::downSampledImageReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QRect & )>(_a, &Document::imageRectUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & )>(_a, &Document::kindDetermined, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & )>(_a, &Document::metaInfoLoaded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & )>(_a, &Document::loaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & )>(_a, &Document::loadingFailed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & , const QUrl & )>(_a, &Document::saved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & )>(_a, &Document::modified, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::metaInfoUpdated, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::isAnimatedUpdated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)(const QUrl & , bool )>(_a, &Document::busyChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Document::*)()>(_a, &Document::allTasksDone, 11))
            return;
    }
}

const QMetaObject *Gwenview::Document::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::Document::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview8DocumentE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QSharedData"))
        return static_cast< QSharedData*>(this);
    return QObject::qt_metacast(_clname);
}

int Gwenview::Document::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::Document::downSampledImageReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gwenview::Document::imageRectUpdated(const QRect & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Gwenview::Document::kindDetermined(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Gwenview::Document::metaInfoLoaded(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Gwenview::Document::loaded(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Gwenview::Document::loadingFailed(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Gwenview::Document::saved(const QUrl & _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void Gwenview::Document::modified(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Gwenview::Document::metaInfoUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Gwenview::Document::isAnimatedUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Gwenview::Document::busyChanged(const QUrl & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void Gwenview::Document::allTasksDone()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
