/********************************************************************************
** Form generated from reading UI file 'redeyereductionwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REDEYEREDUCTIONWIDGET_H
#define UI_REDEYEREDUCTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RedEyeReductionWidget
{
public:
    QHBoxLayout *horizontalLayout_3;
    QStackedWidget *stackedWidget;
    QWidget *mainPage;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer_3;
    QLabel *label;
    QSlider *diameterSlider;
    QSpinBox *diameterSpinBox;
    QSpacerItem *horizontalSpacer_5;
    QDialogButtonBox *mainDialogButtonBox;
    QSpacerItem *horizontalSpacer_4;
    QWidget *notSetPage;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer;
    QLabel *helpTextLabel;
    QSpacerItem *horizontalSpacer_6;
    QDialogButtonBox *helpDialogButtonBox;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *RedEyeReductionWidget)
    {
        if (RedEyeReductionWidget->objectName().isEmpty())
            RedEyeReductionWidget->setObjectName("RedEyeReductionWidget");
        RedEyeReductionWidget->resize(638, 56);
        horizontalLayout_3 = new QHBoxLayout(RedEyeReductionWidget);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        stackedWidget = new QStackedWidget(RedEyeReductionWidget);
        stackedWidget->setObjectName("stackedWidget");
        mainPage = new QWidget();
        mainPage->setObjectName("mainPage");
        horizontalLayout = new QHBoxLayout(mainPage);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);

        label = new QLabel(mainPage);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        diameterSlider = new QSlider(mainPage);
        diameterSlider->setObjectName("diameterSlider");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(diameterSlider->sizePolicy().hasHeightForWidth());
        diameterSlider->setSizePolicy(sizePolicy);
        diameterSlider->setMinimumSize(QSize(120, 0));
        diameterSlider->setMinimum(2);
        diameterSlider->setMaximum(99);
        diameterSlider->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(diameterSlider);

        diameterSpinBox = new QSpinBox(mainPage);
        diameterSpinBox->setObjectName("diameterSpinBox");
        diameterSpinBox->setAlignment(Qt::AlignCenter);
        diameterSpinBox->setMinimum(2);
        diameterSpinBox->setMaximum(99);

        horizontalLayout->addWidget(diameterSpinBox);

        horizontalSpacer_5 = new QSpacerItem(12, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_5);

        mainDialogButtonBox = new QDialogButtonBox(mainPage);
        mainDialogButtonBox->setObjectName("mainDialogButtonBox");
        mainDialogButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        horizontalLayout->addWidget(mainDialogButtonBox);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);

        horizontalLayout->setStretch(0, 1);
        horizontalLayout->setStretch(6, 1);
        stackedWidget->addWidget(mainPage);
        notSetPage = new QWidget();
        notSetPage->setObjectName("notSetPage");
        horizontalLayout_2 = new QHBoxLayout(notSetPage);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, 0);
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        helpTextLabel = new QLabel(notSetPage);
        helpTextLabel->setObjectName("helpTextLabel");

        horizontalLayout_2->addWidget(helpTextLabel);

        horizontalSpacer_6 = new QSpacerItem(12, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_6);

        helpDialogButtonBox = new QDialogButtonBox(notSetPage);
        helpDialogButtonBox->setObjectName("helpDialogButtonBox");
        helpDialogButtonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout_2->addWidget(helpDialogButtonBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        horizontalLayout_2->setStretch(0, 1);
        horizontalLayout_2->setStretch(4, 1);
        stackedWidget->addWidget(notSetPage);

        horizontalLayout_3->addWidget(stackedWidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(diameterSlider);
#endif // QT_CONFIG(shortcut)

        retranslateUi(RedEyeReductionWidget);
        QObject::connect(diameterSlider, &QSlider::valueChanged, diameterSpinBox, &QSpinBox::setValue);
        QObject::connect(diameterSpinBox, &QSpinBox::valueChanged, diameterSlider, &QSlider::setValue);

        stackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(RedEyeReductionWidget);
    } // setupUi

    void retranslateUi(QWidget *RedEyeReductionWidget)
    {
        label->setText(tr2i18n("Size:", nullptr));
        helpTextLabel->setText(tr2i18n("Click on a red eye and choose a size, or double-click to correct instantly.", nullptr));
        (void)RedEyeReductionWidget;
    } // retranslateUi

};

namespace Ui {
    class RedEyeReductionWidget: public Ui_RedEyeReductionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REDEYEREDUCTIONWIDGET_H

