/****************************************************************************
** Meta object code from reading C++ file 'thumbnailview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/lib/thumbnailview/thumbnailview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'thumbnailview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::ThumbnailView::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::ThumbnailView",
        "indexActivated",
        "",
        "QModelIndex",
        "thumbnailSizeChanged",
        "QSize",
        "thumbnailWidthChanged",
        "selectionChangedSignal",
        "QItemSelection",
        "rowsRemovedSignal",
        "parent",
        "start",
        "end",
        "rowsInsertedSignal",
        "setThumbnailWidth",
        "width",
        "setThumbnailAspectRatio",
        "ratio",
        "scrollToSelectedIndex",
        "generateThumbnailsForItems",
        "rowsAboutToBeRemoved",
        "rowsInserted",
        "selectionChanged",
        "selected",
        "deselected",
        "dataChanged",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "startDragFromTouch",
        "QPoint",
        "pos",
        "tapGesture",
        "setZoomParameter",
        "zoomGesture",
        "newZoom",
        "showContextMenu",
        "emitIndexActivatedIfNoModifiers",
        "setThumbnail",
        "KFileItem",
        "QPixmap",
        "fileSize",
        "setBrokenThumbnail",
        "updateThumbnail",
        "QUrl",
        "url",
        "updateThumbnailBusyState",
        "updateBusyIndexes",
        "smoothNextThumbnail"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'indexActivated'
        QtMocHelpers::SignalData<void(const QModelIndex &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'thumbnailSizeChanged'
        QtMocHelpers::SignalData<void(const QSize &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'thumbnailWidthChanged'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'selectionChangedSignal'
        QtMocHelpers::SignalData<void(const QItemSelection &, const QItemSelection &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'rowsRemovedSignal'
        QtMocHelpers::SignalData<void(const QModelIndex &, int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'rowsInsertedSignal'
        QtMocHelpers::SignalData<void(const QModelIndex &, int, int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'setThumbnailWidth'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setThumbnailAspectRatio'
        QtMocHelpers::SlotData<void(qreal)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 17 },
        }}),
        // Slot 'scrollToSelectedIndex'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'generateThumbnailsForItems'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'rowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 10 }, { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 23 }, { 0x80000000 | 8, 24 },
        }}),
        // Slot 'dataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(25, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 26 }, { 0x80000000 | 3, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'dataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(25, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 26 }, { 0x80000000 | 3, 27 },
        }}),
        // Slot 'startDragFromTouch'
        QtMocHelpers::SlotData<void(const QPoint &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'tapGesture'
        QtMocHelpers::SlotData<void(const QPoint &)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setZoomParameter'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomGesture'
        QtMocHelpers::SlotData<void(qreal, const QPoint &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 36 }, { 0x80000000 | 31, 32 },
        }}),
        // Slot 'showContextMenu'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitIndexActivatedIfNoModifiers'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'setThumbnail'
        QtMocHelpers::SlotData<void(const KFileItem &, const QPixmap &, const QSize &, qulonglong)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 2 }, { 0x80000000 | 41, 2 }, { 0x80000000 | 5, 2 }, { QMetaType::ULongLong, 42 },
        }}),
        // Slot 'setBrokenThumbnail'
        QtMocHelpers::SlotData<void(const KFileItem &)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 40, 2 },
        }}),
        // Slot 'updateThumbnail'
        QtMocHelpers::SlotData<void(const QUrl &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'updateThumbnailBusyState'
        QtMocHelpers::SlotData<void(const QUrl &, bool)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'updateBusyIndexes'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'smoothNextThumbnail'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ThumbnailView, qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::ThumbnailView::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>.metaTypes,
    nullptr
} };

void Gwenview::ThumbnailView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ThumbnailView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->indexActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 1: _t->thumbnailSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 2: _t->thumbnailWidthChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->selectionChangedSignal((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 4: _t->rowsRemovedSignal((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 5: _t->rowsInsertedSignal((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->setThumbnailWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->setThumbnailAspectRatio((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 8: _t->scrollToSelectedIndex(); break;
        case 9: _t->generateThumbnailsForItems(); break;
        case 10: _t->rowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 12: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 13: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 14: _t->dataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 15: _t->startDragFromTouch((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 16: _t->tapGesture((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->setZoomParameter(); break;
        case 18: _t->zoomGesture((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 19: _t->showContextMenu(); break;
        case 20: _t->emitIndexActivatedIfNoModifiers((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 21: _t->setThumbnail((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[4]))); break;
        case 22: _t->setBrokenThumbnail((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 23: _t->updateThumbnail((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 24: _t->updateThumbnailBusyState((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->updateBusyIndexes(); break;
        case 26: _t->smoothNextThumbnail(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(const QModelIndex & )>(_a, &ThumbnailView::indexActivated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(const QSize & )>(_a, &ThumbnailView::thumbnailSizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(int )>(_a, &ThumbnailView::thumbnailWidthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(const QItemSelection & , const QItemSelection & )>(_a, &ThumbnailView::selectionChangedSignal, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(const QModelIndex & , int , int )>(_a, &ThumbnailView::rowsRemovedSignal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ThumbnailView::*)(const QModelIndex & , int , int )>(_a, &ThumbnailView::rowsInsertedSignal, 5))
            return;
    }
}

const QMetaObject *Gwenview::ThumbnailView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::ThumbnailView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview13ThumbnailViewE_t>.strings))
        return static_cast<void*>(this);
    return QListView::qt_metacast(_clname);
}

int Gwenview::ThumbnailView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::ThumbnailView::indexActivated(const QModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Gwenview::ThumbnailView::thumbnailSizeChanged(const QSize & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Gwenview::ThumbnailView::thumbnailWidthChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Gwenview::ThumbnailView::selectionChangedSignal(const QItemSelection & _t1, const QItemSelection & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Gwenview::ThumbnailView::rowsRemovedSignal(const QModelIndex & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void Gwenview::ThumbnailView::rowsInsertedSignal(const QModelIndex & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
