/****************************************************************************
** Meta object code from reading C++ file 'touch.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/lib/touch/touch.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'touch.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview5TouchE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::Touch::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview5TouchE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::Touch",
        "PanTriggered",
        "",
        "QPointF",
        "swipeLeftTriggered",
        "swipeRightTriggered",
        "doubleTapTriggered",
        "tapHoldAndMovingTriggered",
        "QPoint",
        "tapTriggered",
        "pinchGestureStarted",
        "twoFingerTapTriggered",
        "pinchZoomTriggered",
        "pinchRotateTriggered"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'PanTriggered'
        QtMocHelpers::SignalData<void(const QPointF &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'swipeLeftTriggered'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'swipeRightTriggered'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleTapTriggered'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tapHoldAndMovingTriggered'
        QtMocHelpers::SignalData<void(const QPoint &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'tapTriggered'
        QtMocHelpers::SignalData<void(const QPoint &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Signal 'pinchGestureStarted'
        QtMocHelpers::SignalData<void(qint64)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 2 },
        }}),
        // Signal 'twoFingerTapTriggered'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pinchZoomTriggered'
        QtMocHelpers::SignalData<void(qreal, const QPoint &, qint64)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 }, { 0x80000000 | 8, 2 }, { QMetaType::LongLong, 2 },
        }}),
        // Signal 'pinchRotateTriggered'
        QtMocHelpers::SignalData<void(qreal)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Touch, qt_meta_tag_ZN8Gwenview5TouchE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::Touch::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview5TouchE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview5TouchE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview5TouchE_t>.metaTypes,
    nullptr
} };

void Gwenview::Touch::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Touch *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->PanTriggered((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 1: _t->swipeLeftTriggered(); break;
        case 2: _t->swipeRightTriggered(); break;
        case 3: _t->doubleTapTriggered(); break;
        case 4: _t->tapHoldAndMovingTriggered((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->tapTriggered((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->pinchGestureStarted((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 7: _t->twoFingerTapTriggered(); break;
        case 8: _t->pinchZoomTriggered((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 9: _t->pinchRotateTriggered((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(const QPointF & )>(_a, &Touch::PanTriggered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)()>(_a, &Touch::swipeLeftTriggered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)()>(_a, &Touch::swipeRightTriggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)()>(_a, &Touch::doubleTapTriggered, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(const QPoint & )>(_a, &Touch::tapHoldAndMovingTriggered, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(const QPoint & )>(_a, &Touch::tapTriggered, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(qint64 )>(_a, &Touch::pinchGestureStarted, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)()>(_a, &Touch::twoFingerTapTriggered, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(qreal , const QPoint & , qint64 )>(_a, &Touch::pinchZoomTriggered, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Touch::*)(qreal )>(_a, &Touch::pinchRotateTriggered, 9))
            return;
    }
}

const QMetaObject *Gwenview::Touch::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::Touch::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview5TouchE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Gwenview::Touch::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::Touch::PanTriggered(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Gwenview::Touch::swipeLeftTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Gwenview::Touch::swipeRightTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Gwenview::Touch::doubleTapTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Gwenview::Touch::tapHoldAndMovingTriggered(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Gwenview::Touch::tapTriggered(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Gwenview::Touch::pinchGestureStarted(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Gwenview::Touch::twoFingerTapTriggered()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Gwenview::Touch::pinchZoomTriggered(qreal _t1, const QPoint & _t2, qint64 _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void Gwenview::Touch::pinchRotateTriggered(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
