/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.04.1/app/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::MainWindow",
        "viewModeChanged",
        "",
        "showStartMainPage",
        "goToUrl",
        "QUrl",
        "setCaption",
        "modified",
        "setActiveViewModeAction",
        "QAction*",
        "action",
        "openDirUrl",
        "slotThumbnailViewIndexActivated",
        "QModelIndex",
        "slotStartMainPageUrlSelected",
        "goUp",
        "toggleSideBar",
        "visible",
        "toggleOperationsSideBar",
        "slotModifiedDocumentListChanged",
        "slotUpdateCaption",
        "caption",
        "slotPartCompleted",
        "slotDirModelNewItems",
        "slotDirListerCompleted",
        "slotSelectionChanged",
        "slotCurrentDirUrlChanged",
        "url",
        "goToPrevious",
        "goToNext",
        "goToFirst",
        "goToLast",
        "updatePreviousNextActions",
        "leaveFullScreen",
        "toggleFullScreen",
        "leaveSpotlightMode",
        "toggleSpotlightMode",
        "toggleSlideShow",
        "updateSlideShowAction",
        "saveCurrent",
        "saveCurrentAs",
        "openFile",
        "openUrl",
        "reload",
        "showDocumentInFullScreen",
        "showConfigDialog",
        "page",
        "loadConfig",
        "print",
        "printPreview",
        "preloadNextUrl",
        "toggleMenuBar",
        "toggleStatusBar",
        "showFirstDocumentReached",
        "showLastDocumentReached",
        "replaceLocation",
        "onFocusChanged",
        "QWidget*",
        "old",
        "now"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showStartMainPage'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goToUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'setCaption'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Slot 'setCaption'
        QtMocHelpers::SlotData<void(const QString &, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Bool, 7 },
        }}),
        // Slot 'setActiveViewModeAction'
        QtMocHelpers::SlotData<void(QAction *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'openDirUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'slotThumbnailViewIndexActivated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Slot 'slotStartMainPageUrlSelected'
        QtMocHelpers::SlotData<void(const QUrl &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'goUp'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSideBar'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'toggleOperationsSideBar'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'slotModifiedDocumentListChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateCaption'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'slotPartCompleted'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirModelNewItems'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDirListerCompleted'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectionChanged'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCurrentDirUrlChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 27 },
        }}),
        // Slot 'goToPrevious'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToNext'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToFirst'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToLast'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePreviousNextActions'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'leaveFullScreen'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void(bool)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'leaveSpotlightMode'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleSpotlightMode'
        QtMocHelpers::SlotData<void(bool)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleSlideShow'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSlideShowAction'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveCurrent'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveCurrentAs'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<void(const QUrl &)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 27 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showDocumentInFullScreen'
        QtMocHelpers::SlotData<void(const QUrl &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'showConfigDialog'
        QtMocHelpers::SlotData<void(int)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'showConfigDialog'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'loadConfig'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'print'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printPreview'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'preloadNextUrl'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleMenuBar'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleStatusBar'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'showFirstDocumentReached'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showLastDocumentReached'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'replaceLocation'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onFocusChanged'
        QtMocHelpers::SlotData<void(QWidget *, QWidget *)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { 0x80000000 | 57, 59 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN8Gwenview10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview10MainWindowE_t>.metaTypes,
    nullptr
} };

void Gwenview::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewModeChanged(); break;
        case 1: _t->showStartMainPage(); break;
        case 2: _t->goToUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->setCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->setActiveViewModeAction((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 6: _t->openDirUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->slotThumbnailViewIndexActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->slotStartMainPageUrlSelected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 9: _t->goUp(); break;
        case 10: _t->toggleSideBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->toggleOperationsSideBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotModifiedDocumentListChanged(); break;
        case 13: _t->slotUpdateCaption((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->slotPartCompleted(); break;
        case 15: _t->slotDirModelNewItems(); break;
        case 16: _t->slotDirListerCompleted(); break;
        case 17: _t->slotSelectionChanged(); break;
        case 18: _t->slotCurrentDirUrlChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 19: _t->goToPrevious(); break;
        case 20: _t->goToNext(); break;
        case 21: _t->goToFirst(); break;
        case 22: _t->goToLast(); break;
        case 23: _t->updatePreviousNextActions(); break;
        case 24: _t->leaveFullScreen(); break;
        case 25: _t->toggleFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->leaveSpotlightMode(); break;
        case 27: _t->toggleSpotlightMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->toggleSlideShow(); break;
        case 29: _t->updateSlideShowAction(); break;
        case 30: _t->saveCurrent(); break;
        case 31: _t->saveCurrentAs(); break;
        case 32: _t->openFile(); break;
        case 33: _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 34: _t->reload(); break;
        case 35: _t->showDocumentInFullScreen((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 36: _t->showConfigDialog((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->showConfigDialog(); break;
        case 38: _t->loadConfig(); break;
        case 39: _t->print(); break;
        case 40: _t->printPreview(); break;
        case 41: _t->preloadNextUrl(); break;
        case 42: _t->toggleMenuBar(); break;
        case 43: _t->toggleStatusBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->showFirstDocumentReached(); break;
        case 45: _t->showLastDocumentReached(); break;
        case 46: _t->replaceLocation(); break;
        case 47: _t->onFocusChanged((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 47:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::viewModeChanged, 0))
            return;
    }
}

const QMetaObject *Gwenview::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int Gwenview::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::MainWindow::viewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
